==> zio-aws-apigatewayv2_3-5.17.125.1-sources.jar: zio/aws/apigatewayv2/model/DeleteRouteSettingsRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteRouteSettingsRequest(
    apiId: __string,
    routeKey: __string,
    stageName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest = {
    import DeleteRouteSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .routeKey(__string.unwrap(routeKey): java.lang.String)
      .stageName(__string.unwrap(stageName): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.wrap(buildAwsValue())
}
object DeleteRouteSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest =
      zio.aws.apigatewayv2.model
        .DeleteRouteSettingsRequest(apiId, routeKey, stageName)
    def apiId: __string
    def routeKey: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteKey: ZIO[Any, Nothing, __string] = ZIO.succeed(routeKey)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ) extends zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val routeKey: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeKey())
    override val stageName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.stageName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ): zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_3-5.17.130.8-sources.jar: zio/aws/apigatewayv2/model/DeleteRouteSettingsRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteRouteSettingsRequest(
    apiId: __string,
    routeKey: __string,
    stageName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest = {
    import DeleteRouteSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .routeKey(routeKey: java.lang.String)
      .stageName(stageName: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.wrap(buildAwsValue())
}
object DeleteRouteSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest =
      zio.aws.apigatewayv2.model
        .DeleteRouteSettingsRequest(apiId, routeKey, stageName)
    def apiId: __string
    def routeKey: __string
    def stageName: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getRouteKey: ZIO[Any, Nothing, __string] = ZIO.succeed(routeKey)
    def getStageName: ZIO[Any, Nothing, __string] = ZIO.succeed(stageName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ) extends zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val routeKey: __string = impl.routeKey(): __string
    override val stageName: __string = impl.stageName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteRouteSettingsRequest
  ): zio.aws.apigatewayv2.model.DeleteRouteSettingsRequest.ReadOnly =
    new Wrapper(impl)
}
